# Release history

### 0.0.4
* Update Docker bundling commands. Use bash to move files between directories instead of installing with `-t` flag.
Related issue: https://github.com/pypa/pip/issues/103

### 0.0.1
* Initial build.
* Elasticsearch-python 7.9.1.
* Docker image for asset building: python:3.9.